**this file will be overwriten! **

 - Write documentation describing your app, files starting __ are ignored.

 - or add to `links.json`

## Settings

 - *activation*: <i>pid_feedback_control</i>

 - *run_state*: None

 - *progress*: None

 - *profile*: Run a profile on the run to find performance problems

 - *Kp*: None

 - *Ki*: None

 - *Kd*: None

 - *setpoint*: None

 - *sensor*: choose a setting that supports read_from_hardware.

 - *plant_input*: choose a setting that has a hardware_set_func

 - *timeout*: used to define <b>terminate</b> condition <i>timeout</i> and <i>error_tol_with_timeout</i>, ignored otherwise

 - *error*: None

 - *error_tol*: used to define <b>terminate</b> condition <i>error_tol</i> and <i>error_tol_with_timeout</i>, ignored otherwise

 - *terminate*: condition for pid_feedback_control to end.

 - *min_plant_input*: minimum plant input value.

 - *max_plant_input*: maximum plant input value.

 - *save_h5*: None

